==> haskell-bv-sized-1.0.6-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bv-sized.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bv-sized
version:              1.0.6
visibility:           public
id:                   bv-sized-1.0.6-JqbHO9cTGjR8dzXBLVcs8z
key:                  bv-sized-1.0.6-JqbHO9cTGjR8dzXBLVcs8z
license:              BSD-3-Clause
copyright:            Galois Inc., Ben Selfridge March 2018
maintainer:           benselfridge@galois.com
author:               Ben Selfridge
homepage:             https://github.com/GaloisInc/bv-sized
synopsis:
    a bitvector datatype that is parameterized by the vector width

description:
    This module defines a width-parameterized bitvector type and various associated operations.

category:             Bit Vectors
abi:                  ba47067bb7ca84c221a9bc3cc3e00898
exposed:              True
exposed-modules:
    Data.BitVector.Sized Data.BitVector.Sized.Overflow
    Data.BitVector.Sized.Signed Data.BitVector.Sized.Unsigned

hidden-modules:
    Data.BitVector.Sized.Internal Data.BitVector.Sized.Panic

import-dirs:          /usr/lib/ghc-9.4.8/site-local/bv-sized-1.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bv-sized-1.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bv-sized-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bv-sized
hs-libraries:         HSbv-sized-1.0.6-JqbHO9cTGjR8dzXBLVcs8z
depends:
    base-4.17.2.1 bitwise-1.0.0.1-3bPSq5MuUWO10YtzdDAgZE
    bytestring-0.11.5.3 deepseq-1.4.8.0
    panic-0.4.0.1-9Mho20XcACeAG1iUCpMASP
    parameterized-utils-2.1.10.0-8Nc0zKVCHlLFqFMxgCICfY
    random-1.2.1.2-ChMGeZ0Ar0Oa3oanqFKyA
    th-lift-0.8.5-3bCWMcLwp8dEXoRnv4Yrhx

haddock-interfaces:   /usr/share/doc/haskell-bv-sized/html/bv-sized.haddock
haddock-html:         /usr/share/doc/haskell-bv-sized/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bv-sized-1.0.6-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bv-sized.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bv-sized
version:              1.0.6
visibility:           public
id:                   bv-sized-1.0.6-Gef1jby7HRh1vIEyKGynam
key:                  bv-sized-1.0.6-Gef1jby7HRh1vIEyKGynam
license:              BSD-3-Clause
copyright:            Galois Inc., Ben Selfridge March 2018
maintainer:           benselfridge@galois.com
author:               Ben Selfridge
homepage:             https://github.com/GaloisInc/bv-sized
synopsis:
    a bitvector datatype that is parameterized by the vector width

description:
    This module defines a width-parameterized bitvector type and various associated operations.

category:             Bit Vectors
abi:                  73c91b875c367cada2d4d2f3b719fded
exposed:              True
exposed-modules:
    Data.BitVector.Sized Data.BitVector.Sized.Overflow
    Data.BitVector.Sized.Signed Data.BitVector.Sized.Unsigned

hidden-modules:
    Data.BitVector.Sized.Internal Data.BitVector.Sized.Panic

import-dirs:          /usr/lib/ghc-9.4.8/site-local/bv-sized-1.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bv-sized-1.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bv-sized-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bv-sized
hs-libraries:         HSbv-sized-1.0.6-Gef1jby7HRh1vIEyKGynam
depends:
    base-4.17.2.1 bitwise-1.0.0.1-DQkyqTUaDuRE48LcqKlLYA
    bytestring-0.11.5.3 deepseq-1.4.8.0
    panic-0.4.0.1-9Mho20XcACeAG1iUCpMASP
    parameterized-utils-2.1.10.0-8cnuerUx8BREazqaDOi12G
    random-1.2.1.2-FNtVSr9AyR5Fv650rjDfzJ
    th-lift-0.8.5-3bCWMcLwp8dEXoRnv4Yrhx

haddock-interfaces:   /usr/share/doc/haskell-bv-sized/html/bv-sized.haddock
haddock-html:         /usr/share/doc/haskell-bv-sized/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
